@@ -2,12 +2,13 @@ package Net::IPAM::IP;
 
 use strict;
 use warnings;
-our $VERSION = '1.06';
+our $VERSION = '1.07';
 
 use Socket qw/AF_INET AF_INET6/;
 
 # On some platforms, inet_pton accepts various forms of invalid input or discards valid input.
 # In this case use a (slower) pure perl implementation for Socket::inet_pton.
+# and also for Socket::inet_ntop, I don't trust that too.
 BEGIN {
   if (    # wrong valid
        defined Socket::inet_pton( AF_INET,  '010.0.0.1' )
@@ -23,6 +24,7 @@ BEGIN {
   {
     no warnings 'redefine';
     *Socket::inet_pton = \&_inet_pton_pp;
+    *Socket::inet_ntop = \&_inet_ntop_pp;
   }
 }
 
@@ -92,10 +94,10 @@ sub new {
 
   # IPv4-mapped-IPv6
   if ( index( $_[1], '.' ) >= 0 ) {
-		my $ip4m6 = $_[1];
+    my $ip4m6 = $_[1];
 
     # remove leading ::ffff: or return undef
-		return unless $ip4m6 =~ s/^::ffff://i;
+    return unless $ip4m6 =~ s/^::ffff://i;
 
     my $n = Socket::inet_pton( AF_INET, $ip4m6 ) // return;
 
@@ -421,21 +423,30 @@ sub _inet_ntop_v6_pp {
   my $ip = join( ':', unpack( 'H4' x 8, $n ) );
 
   # squash leading zeroes, rule (2)
+  # 2001:db8:85a3:0:0:8a2e:370:7334
   $ip =~ s/\b 0{1,3}//gx;
 
   # find all consecutive groups containing zeros
-	my $rx = qr/(?:^|:) [0:]+ /x;
+  my $rx     = qr/(?:^|:) [0:]+ /x;
   my @groups = $ip =~ m/$rx/g;
 
   # find longest group (count zeros with tr///), rule (3)
   # count zeros with tr///
-  my $max = '';
-  $_ =~ tr/0/0/ > $max =~ tr/0/0/ and $max = $_ foreach @groups;
+  my $max_str   = '';
+  my $max_zeros = 0;
+
+  foreach my $match (@groups) {
+    my $zeroes = $match =~ tr/0/0/;
+    if ( $zeroes > $max_zeros ) {
+      $max_zeros = $zeroes;
+      $max_str   = $match;
+    }
+  }
 
   # the substitution may only be applied once in the address, rule (3,4)
   # "::" is not used to shorten just a single 0 field
-  if ( $max =~ tr/0/0/ >= 2 ) {
-    $ip =~ s/$max/::/;
+  if ( $max_zeros >= 2 ) {
+    $ip =~ s/$max_str/::/;
   }
 
   return $ip;
